@@ -32,7 +32,7 @@ describe 'horizon' do
           :refreshonly => true,
       })}
       it {
-        if facts[:os_package_type] == 'rpm'
+        if facts[:osfamily] == 'RedHat'
           is_expected.to contain_concat(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_cache]')
           is_expected.to contain_concat(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_compress]')
         else
@@ -60,7 +60,7 @@ describe 'horizon' do
           "LOGOUT_URL = '#{platforms_params[:root_url]}/auth/logout/'",
           "LOGIN_REDIRECT_URL = '#{platforms_params[:root_url]}/'",
           "ALLOWED_HOSTS = ['some.host.tld', ]",
-          "  'identity': 3,",
+          "    'identity': 3,",
           'HORIZON_CONFIG["password_autocomplete"] = "off"',
           'HORIZON_CONFIG["images_panel"] = "legacy"',
           "SECRET_KEY = 'elj1IWiLoWHgcyYxFVLj7cM5rGOOxWl0'",
@@ -73,6 +73,7 @@ describe 'horizon' do
           "    'enable_quotas': True,",
           "    'enable_security_group': True,",
           'API_RESULT_LIMIT = 1000',
+          'API_RESULT_PAGE_SIZE = 20',
           'DROPDOWN_MAX_ITEMS = 30',
           'TIME_ZONE = "UTC"',
           "            'handlers': ['file'],",
@@ -106,7 +107,8 @@ describe 'horizon' do
           :secondary_endpoint_type        => 'ANY-VALUE',
           :django_debug                   => true,
           :site_branding                  => 'mysite',
-          :api_result_limit               => 4682,
+          :api_result_limit               => 2000,
+          :api_result_page_size           => 40,
           :dropdown_max_items             => 123,
           :compress_offline               => false,
           :hypervisor_options             => {'can_set_mount_point' => false, 'can_set_password' => true },
@@ -149,15 +151,16 @@ describe 'horizon' do
           'CSRF_COOKIE_SECURE = True',
           'SESSION_COOKIE_SECURE = True',
           'SESSION_COOKIE_HTTPONLY = True',
-          "  'identity': 2.0,",
+          "    'identity': 2.0,",
           "OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT = True",
           "OPENSTACK_KEYSTONE_DEFAULT_DOMAIN = 'domain.tld'",
           'HORIZON_CONFIG["password_autocomplete"] = "on"',
           'HORIZON_CONFIG["images_panel"] = "angular"',
           "SECRET_KEY = 'elj1IWiLoWHgcyYxFVLj7cM5rGOOxWl0'",
-          "                'DEAD_RETRY': 1,",
-          "                'SERVER_RETRIES': 1,",
-          "                'SOCKET_TIMEOUT': 1,",
+          "        'OPTIONS': {",
+          "            'DEAD_RETRY': 1,",
+          "            'SERVER_RETRIES': 1,",
+          "            'SOCKET_TIMEOUT': 1,",
           "        'BACKEND': 'horizon.backends.memcached.HorizonMemcached',",
           "        'LOCATION': '10.0.0.1:11211',",
           'SESSION_ENGINE = "django.contrib.sessions.backends.cache"',
@@ -192,12 +195,13 @@ describe 'horizon' do
           "    'enable_scheduler_hints': True,",
           'OPENSTACK_ENDPOINT_TYPE = "internalURL"',
           'SECONDARY_ENDPOINT_TYPE = "ANY-VALUE"',
-          'API_RESULT_LIMIT = 4682',
+          'API_RESULT_LIMIT = 2000',
+          'API_RESULT_PAGE_SIZE = 40',
           'DROPDOWN_MAX_ITEMS = 123',
           'TIME_ZONE = "Asia/Shanghai"',
           "AVAILABLE_THEMES = [",
-          "  ('default', 'Default', 'themes/default'),",
-          "  ('material', 'Material', 'themes/material'),",
+          "    ('default', 'Default', 'themes/default'),",
+          "    ('material', 'Material', 'themes/material'),",
           "]",
           "DEFAULT_THEME = 'default'",
           "            'level': 'DEBUG',",
@@ -694,7 +698,20 @@ describe 'horizon' do
       end
       it 'sets HORIZON_IMAGES_UPLOAD_MODE in local_settings.py' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-	  'HORIZON_IMAGES_UPLOAD_MODE = direct',
+          'HORIZON_IMAGES_UPLOAD_MODE = "direct"',
+        ])
+      end
+    end
+
+    context 'with upload mode with quotes' do
+      before do
+        params.merge!({
+          :horizon_upload_mode  => '"direct"',
+        })
+      end
+      it 'sets HORIZON_IMAGES_UPLOAD_MODE in local_settings.py' do
+        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
+          'HORIZON_IMAGES_UPLOAD_MODE = "direct"',
         ])
       end
     end
@@ -751,7 +768,7 @@ describe 'horizon' do
       let(:platforms_params) do
         case facts[:osfamily]
         when 'Debian'
-          if facts[:os_package_type] == 'debian'
+          if facts[:operatingsystem] == 'Debian'
             { :config_file      => '/etc/openstack-dashboard/local_settings.py',
               :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
               :package_name     => 'openstack-dashboard-apache',
