@@ -359,7 +359,7 @@ describe 'horizon::wsgi::apache' do
       )}
     end
 
-    context 'with listen_ssl and ssl_redirect with a empty root_url' do
+    context 'with listen_ssl and ssl_redirect with an empty root_url' do
       before do
         params.merge!({
           :listen_ssl        => true,
@@ -520,10 +520,6 @@ describe 'horizon::wsgi::apache' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        if facts[:operatingsystem] == 'Debian'
-          facts.merge!( :os_package_type => 'debian' )
-        end
-
         facts.merge!(OSDefaults.get_facts({
           :fqdn           => 'some.host.tld',
           :concat_basedir => '/var/lib/puppet/concat',
